@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2023 Raspberry Pi (Trading) Ltd.
+Copyright (c) 2023 Raspberry Pi
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -89,7 +89,7 @@ int can_configure (const char *type)
         if (!dlerror ())
         {
             cptr = func_config_params ();
-            if (cptr->type != CONF_NONE) can_conf = TRUE;
+            if (cptr->type != CONF_TYPE_NONE) can_conf = TRUE;
         }
         dlclose (wid_lib);
     }
@@ -141,7 +141,7 @@ static gboolean read_lib (const char *type, char **name, gboolean *config)
         if (!dlerror ())
         {
             cptr = func_config_params ();
-            if (cptr->type != CONF_NONE) *config = TRUE;
+            if (cptr->type != CONF_TYPE_NONE) *config = TRUE;
         }
 
         /*
@@ -452,11 +452,11 @@ int plugin_config_dialog (const char *type)
         if (!dlerror ())
         {
             cptr = func_config_params ();
-            while (cptr->type != CONF_NONE)
+            while (cptr->type != CONF_TYPE_NONE)
             {
                 control = NULL;
                 hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
-                if (cptr->type == CONF_LABEL)
+                if (cptr->type == CONF_TYPE_LABEL)
                     strval = g_strdup_printf ("%s", dgettext (package, cptr->label));
                 else
                     strval = g_strdup_printf ("%s:", dgettext (package, cptr->label));
@@ -466,30 +466,41 @@ int plugin_config_dialog (const char *type)
                 key = g_strdup_printf ("%s_%s", type, cptr->name);
                 switch (cptr->type)
                 {
-                    case CONF_BOOL :    control = gtk_switch_new ();
+                    case CONF_TYPE_BOOL :
+                                        control = gtk_switch_new ();
                                         gtk_switch_set_active (GTK_SWITCH (control), get_config_bool (key));
                                         break;
 
-                    case CONF_INT :     control = gtk_spin_button_new_with_range (0, 1000, 1); //!!!!!
+                    case CONF_TYPE_INT :
+                                        control = gtk_spin_button_new_with_range (0, 1000, 1); //!!!!!
                                         if (space == -1)
                                             gtk_spin_button_set_value (GTK_SPIN_BUTTON (control), get_config_int (key));
                                         else
                                             gtk_spin_button_set_value (GTK_SPIN_BUTTON (control), space);
                                         break;
 
-                    case CONF_STRING :  control = gtk_entry_new ();
+                    case CONF_TYPE_STRING :
+                                        control = gtk_entry_new ();
                                         get_config_string (key, &strval);
                                         gtk_entry_set_text (GTK_ENTRY (control), strval);
                                         g_free (strval);
                                         break;
 
-                    case CONF_COLOUR :  control = gtk_color_button_new ();
+                    case CONF_TYPE_COLOUR :
+                                        control = gtk_color_button_new ();
                                         get_config_string (key, &strval);
                                         gdk_rgba_parse (&col, strval);
                                         g_free (strval);
                                         gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (control), &col);
                                         break;
 
+                    case CONF_TYPE_FONT :
+                                        control = gtk_font_button_new ();
+                                        get_config_string (key, &strval);
+                                        gtk_font_chooser_set_font (GTK_FONT_CHOOSER (control), strval);
+                                        g_free (strval);
+                                        break;
+
                     default :           break;
                 }
                 if (control)
@@ -498,7 +509,7 @@ int plugin_config_dialog (const char *type)
                     gtk_box_pack_end (GTK_BOX (hbox), control, FALSE, FALSE, 0);
                     gtk_container_add (GTK_CONTAINER (box), hbox);
                 }
-                else if (cptr->type == CONF_LABEL)
+                else if (cptr->type == CONF_TYPE_LABEL)
                 {
                     gtk_container_add (GTK_CONTAINER (box), hbox);
                 }
@@ -524,7 +535,7 @@ int plugin_config_dialog (const char *type)
 
     if (gtk_dialog_run (GTK_DIALOG (cdlg)) == GTK_RESPONSE_OK)
     {
-        user_file = g_build_filename (g_get_user_config_dir (), "wf-panel-pi.ini", NULL);
+        user_file = g_build_filename (g_get_user_config_dir (), "wf-panel-pi", "wf-panel-pi.ini", NULL);
         kf = g_key_file_new ();
         g_key_file_load_from_file (kf, user_file, G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, NULL);
 
@@ -556,6 +567,12 @@ int plugin_config_dialog (const char *type)
                     g_key_file_set_string (kf, "panel", gtk_widget_get_name (control), strval);
                     g_free (strval);
                 }
+                else if (GTK_IS_FONT_BUTTON (control))
+                {
+                    strval = gtk_font_chooser_get_font (GTK_FONT_CHOOSER (control));
+                    g_key_file_set_string (kf, "panel", gtk_widget_get_name (control), strval);
+                    g_free (strval);
+                }
             }
             elem = elem->next;
         }
@@ -703,7 +720,7 @@ static void write_config (void)
     gsize len;
 
     // construct the file path
-    char *user_file = g_build_filename (g_get_user_config_dir (), "wf-panel-pi.ini", NULL);
+    char *user_file = g_build_filename (g_get_user_config_dir (), "wf-panel-pi", "wf-panel-pi.ini", NULL);
 
     // read in data from file to a key file
     GKeyFile *kf = g_key_file_new ();
